Index: /fact/tools/rootmacros/PulseTemplates/rootfilehandler.C
===================================================================
--- /fact/tools/rootmacros/PulseTemplates/rootfilehandler.C	(revision 13659)
+++ /fact/tools/rootmacros/PulseTemplates/rootfilehandler.C	(revision 13660)
@@ -30,5 +30,5 @@
 
 TFile*
-OpenRootFile(
+ChooseRootFileToWrite(
         TString    loc_fname,
         int             verbosityLevel
@@ -52,5 +52,5 @@
     return output_rootfile;
 }
 //end of OpenRootFile
 //----------------------------------------------------------------------------
 
@@ -89,5 +89,5 @@
 
     TFile* output_rootfile = NULL;
-    output_rootfile = OpenRootFile( loc_fname, verbosityLevel);
+    output_rootfile = ChooseRootFileToWrite( loc_fname, verbosityLevel);
 
     if (verbosityLevel > 2) cout << endl
@@ -121,5 +121,5 @@
 TString
 CreateSubDirName(
-        TString title
+        TString         title
         )
 {
@@ -131,2 +131,24 @@
 //----------------------------------------------------------------------------
 
+TFile*
+OpenRootFile(
+        TString         path,
+        TString         filename,
+        int             verbosityLevel
+        )
+{
+    if (verbosityLevel > 1)
+    {
+        cout << "...opening root-file: ";
+    }
+
+    path += filename;
+    TFile* file = TFile::Open( path );
+
+    if (verbosityLevel > 1)
+    {
+        cout << path ;
+        cout << " ...successfull" << endl;
+    }
+    return file;
+}
@@ -52,5 +52,5 @@
     return output_rootfile;
 }
-//end of OpenRootFile
+//end of WriteInRootFile
 //----------------------------------------------------------------------------
 
